from sqlalchemy import Column, DateTime, Float, ForeignKey, Integer, String
from sqlalchemy.orm import relationship
from sqlalchemy.sql import func

from app.db.base_class import Base


class Song(Base):
    id = Column(String, primary_key=True, index=True)
    title = Column(String, index=True, nullable=False)
    artist_id = Column(String, ForeignKey("artist.id"), nullable=False)
    album_id = Column(String, ForeignKey("album.id"), nullable=True)
    file_path = Column(String, nullable=False)
    duration = Column(Float, nullable=True)  # Duration in seconds
    genre = Column(String, nullable=True)
    track_number = Column(Integer, nullable=True)
    created_at = Column(DateTime(timezone=True), server_default=func.now())
    updated_at = Column(DateTime(timezone=True), onupdate=func.now())
    
    # Relationships
    artist = relationship("Artist", back_populates="songs")
    album = relationship("Album", back_populates="songs")
    playlists = relationship("PlaylistSong", back_populates="song", cascade="all, delete-orphan")